pub struct VerifierArgs {
pub verifier: Option<VerificationProviderType>,
pub verifier_api_key: Option<String>,
pub verifier_url: Option<String>,
}Expand description
Verification provider arguments
Fields
verifier: Option<VerificationProviderType>The contract verification provider to use.
verifier_api_key: Option<String>The verifier API KEY, if using a custom provider.
verifier_url: Option<String>The verifier URL, if using a custom provider.
Implementations
Sourceimpl VerifierArgs
impl VerifierArgs
Sourcepub fn effective_type(&self) -> VerificationProviderType
pub fn effective_type(&self) -> VerificationProviderType
Returns the effective verifier type, defaulting to Sourcify if not explicitly set.
Note: this is the defaulted CLI value, not the actually-selected provider after
considering ETHERSCAN_API_KEY / chain support. Use Self::resolve for that.
Sourcepub const fn is_explicitly_set(&self) -> bool
pub const fn is_explicitly_set(&self) -> bool
Returns true if --verifier was explicitly provided by the user.
Sourcepub fn resolve_api_key<'a>(
&'a self,
etherscan_key: Option<&'a str>,
) -> Option<&'a str>
pub fn resolve_api_key<'a>( &'a self, etherscan_key: Option<&'a str>, ) -> Option<&'a str>
Resolves the API key with consistent precedence: explicit --verifier-api-key first,
then the etherscan config key.
Sourcepub async fn check_credentials(
&self,
api_key: Option<&str>,
chain: Chain,
config: &Config,
) -> Result<()>
pub async fn check_credentials( &self, api_key: Option<&str>, chain: Chain, config: &Config, ) -> Result<()>
Makes a lightweight network call to validate that credentials are accepted by the verifier.
api_key must be the already-merged API key (CLI --verifier-api-key takes
precedence over config), as returned by Self::resolve_api_key.
Sourcepub fn resolve(
&self,
etherscan_key: Option<&str>,
chain: Option<Chain>,
) -> VerificationProviderType
pub fn resolve( &self, etherscan_key: Option<&str>, chain: Option<Chain>, ) -> VerificationProviderType
Resolves the actual verification provider that will be used at runtime, taking into
account the explicit --verifier, the presence of ETHERSCAN_API_KEY, and whether the
target chain has a known Etherscan API URL.
Resolution rules (mirrors VerificationProviderType::client):
- If
--verifierwas explicitly set, that wins. - Otherwise, if an Etherscan API key is set AND the chain is supported (or a custom
--verifier-urlis provided), use Etherscan. - Otherwise, fall back to Sourcify.